@@ -1,5 +1,6 @@
 #!/usr/bin/python
 
+from optparse import OptionParser
 import os
 import os.path
 import time
@@ -30,13 +31,18 @@ def do_install_remove(backend, pkgname):
 
 if __name__ == "__main__":
 
+    parser = OptionParser()
+    parser.add_option("-p", "--profile", dest="profile", 
+                      default="profile/auto-install-tester/",
+                      help="base profile dir")
+
+    (options, args) = parser.parse_args()
+
     # create backend
     apt_pkg.Config.Set("APT::Architecture","i386")
-
-    # FIXME: hardcoding pathes sucks
-    basedir = "./profile/jaunty-auto-install"
+    basedir = os.path.abspath(os.path.dirname(options.profile))
     aptbasedir = os.path.join(basedir,"auto-install-test")
-    profile = os.path.join(basedir, "DistUpgrade.cfg")
+
 
     # create apt dirs if needed
     for d in ["etc/apt/",
@@ -47,10 +53,10 @@ if __name__ == "__main__":
             os.makedirs(os.path.join(aptbasedir,d))
 
 
-    backend = UpgradeTestBackendQemu(profile, profile)
+    backend = UpgradeTestBackendQemu(options.profile)
     backend.bootstrap()
 
-    # copy status file
+    # copy status file from image to aptbasedir
     backend.start()
     print "copy status file"
     backend._copyFromImage("/var/lib/dpkg/status",
@@ -79,7 +85,8 @@ if __name__ == "__main__":
     backend._runInImage(["apt-get","update"])
 
     # setup dirs
-    resultdir = os.path.join(basedir,"result")
+    resultdir = backend.resultdir
+    print "Using resultdir: '%s'" % resultdir
     failures = open(os.path.join(resultdir,"failures.txt"),"w")
 
     # set with package that have been tested successfully
@@ -125,15 +132,16 @@ if __name__ == "__main__":
             failures.write("%s markInstall()\n " % pkg.name)
             continue
         
-        statusfile.write("%s\n" % pkg.name)
+        statusfile.write("%s-%s\n" % (pkg.name, pkg.candidateVersion))
         if not do_install_remove(backend, pkg.name):
             # on failure, re-run in a clean env so that the log
             # is more meaningful
+            # FIXME: ignore  404 because they are most likely transient
             print "pkg: %s failed, re-testing in a clean(er) environment" % pkg.name
             backend.restoreVMSnapshot("clean-base")
             backend.start()
             if not do_install_remove(backend, pkg.name):
-                outname = os.path.join(basedir,"result","%s-fail.txt" % pkg.name)
+                outname = os.path.join(resultdir,"%s-fail.txt" % pkg.name)
                 failures.write("failed to install/remove %s (log at %s)" % (pkg.name, outname))
                 time.sleep(5)
                 backend._copyFromImage("/var/log/apt/term.log",outname)
